# -*- coding: UTF-8 -*-

# AppModule pour TeamViewer 14 et 15, versions gratuites.
# Page de téléchargement:
#https://www.progaccess.net/article.php?id=227
# Date: 06/04/2022
# Version: 1.1
# basé sur l'extension teamviewer version 2.0 de 2014, auteurs "Noelia Ruiz Martínez et Mesar Hameed".

import appModuleHandler
import addonHandler
import os
import api
import ui
import winUser
import windowUtils
import NVDAObjects.IAccessible
from NVDAObjects.IAccessible import IAccessible, getNVDAObjectFromPoint
from speech import speakSpelling
import scriptHandler
import wx
import UIAHandler
from keyboardHandler import KeyboardInputGesture
from time import sleep
from tones import beep
from UIAHandler import handler
clientObject = handler.clientObject
cO=clientObject
CPC=clientObject.CreatePropertyCondition
addonHandler.initTranslation()

_curAddon = addonHandler.getCodeAddon()
_scriptCategory =_curAddon.manifest['summary']

class AppModule(appModuleHandler.AppModule):
	
	def event_NVDAObject_init(self, obj):
		pass # self.fenPub()
	
	def  fenPub(self) :
		try :
			if "TeamViewer" in api.getForegroundObject().name and not api.getForegroundObject().windowClassName==	"MainWindowFull" :
				wx.CallLater (200,KeyboardInputGesture.fromName ("alt+F4").send )
		except: pass	
	
	def versionTV(self) :
		version=int(api.getFocusObject().appModule.productVersion.split(".")[0])
		return version
		
	def estVersionQS(self) :
		oCondition=CPC(30003 ,50004)
		hd=api.getForegroundObject().windowHandle
		try :
			elements=cO.ElementFromHandle(hd).FindAll(4,oCondition)
			nb=elements.Length
			if nb>2 : return False
			else : return True
		except : return False

	def listEditControl(self) :
		oCondition=CPC(30003 ,50004)
		hd=api.getForegroundObject().windowHandle
		listVal=[]
		try :
			elements=cO.ElementFromHandle(hd).FindAll(4,oCondition)
			nb=elements.Length
			version=self.versionTV()
			i0= (0 if (nb<3 or version<14) else 1)
			for i in range (i0,nb) : #0
				val=elements.GetElement(i).GetCurrentPropertyValue(30045)
				listVal.append((val))
			return listVal
		except :return ui.message (u" Aucun élément trouvé")

	def script_sayID(self, gesture):
		listVal=self.listEditControl()
		val1=listVal[0]
		if scriptHandler.getLastScriptRepeatCount() > 0:
			wx.CallAfter (speakSpelling,val1)
		else :
			ui.message("Votre ID : "+ val1)
	script_sayID.__doc__ = _(u"dit ou épelle l'ID de l'ordinateur local.")
	script_sayID.category = _scriptCategory
			
	def script_sayPasseword(self, gesture):
		listVal=self.listEditControl()
		val2=listVal[1]
		if scriptHandler.getLastScriptRepeatCount() > 0:
			wx.CallAfter (speakSpelling,val2)
		else :
			ui.message("Mot de passe : ")
			wx.CallAfter (speakSpelling,val2)
	script_sayPasseword.__doc__ = _(u"dit ou épelle le mot de passe de l'ordinateur local.")
	script_sayPasseword.category = _scriptCategory
	
	def script_entrerIDDistant(self, gesture):
		oCondition=CPC(30003 ,50004)
		hd=api.getForegroundObject().windowHandle
		listVal1=[]
		try :
			elements=cO.ElementFromHandle(hd).FindAll(4,oCondition)
			nb=elements.Length
			if nb==2 : return ui.message (u"Non disponible avec Teamviewer QS")  
			for i in range (0,nb) :
				val=elements.GetElement(i).GetCurrentPropertyValue(30045)
				listVal1.append((val))
		except : 
			beep(150,50)
			print (u"Problème pour ID distant")  
			return 
		nb=(3 if self.versionTV()>13 else 2)
		val3=listVal1[nb]
		locat=elements.GetElement(nb).GetCurrentPropertyValue(30001)
		(x,y)=(int(locat[0])+int(locat[2]/2),int(locat[1])+int(locat[3]/2))
		winUser.setCursorPos(x,y)
		winUser.mouse_event(winUser.MOUSEEVENTF_LEFTDOWN,0,0,None,None)
		sleep(0.1)
		winUser.mouse_event(winUser.MOUSEEVENTF_LEFTUP,0,0,None,None)
		if scriptHandler.getLastScriptRepeatCount() > 0:
			o=getNVDAObjectFromPoint(x,y)
			o.setFocus() 
			o.doAction()
		if scriptHandler.getLastScriptRepeatCount() ==0:
			ui.message(str(val3))
	script_entrerIDDistant.__doc__ = _("In the main dialog of TeamViewer, moves the focus to the external ID field of the selected tab.")
			
	def script_copyData(self, gesture): 
		val1=self.listEditControl()[0]
		val2=self.listEditControl()[1]
		data = _("ID: {idValue} - Mot de passe: {passwordValue}").format(idValue=val1, passwordValue=val2)
		if api.copyToClip(data):
			ui.message(u"L'ID et le mot de passe sont copiés dans le presse-papier.")
	script_copyData.__doc__ = "Copie l'ID et le mot de passe dans le presse-papier."
	script_copyData.category = _scriptCategory
	
	def script_fermerFenetre(self, gesture):  # a modifier
		def callback() :
			if "TeamViewer" in api.getForegroundObject().name and not api.getForegroundObject().windowClassName==	"MainWindowFull" : 
				wx.CallLater (100,KeyboardInputGesture.fromName ("alt+F4").send )
			else : return 
		
		if not self.estVersionQS(): 
			beep(150,50)
			return 
		bouton = None
		try: 
			bouton = NVDAObjects.IAccessible.getNVDAObjectFromEvent(windowUtils.findDescendantWindow(api.getForegroundObject().windowHandle, visible=True, controlID=1638), winUser.OBJID_CLIENT, 0) 
		except : 
			try:
				bouton = NVDAObjects.IAccessible.getNVDAObjectFromEvent(windowUtils.findDescendantWindow(api.getForegroundObject().windowHandle, visible=True, controlID=40000), winUser.OBJID_CLIENT, 0) 
			except:
				print (u"bouton annuler non trouvé")
				KeyboardInputGesture.fromName ("alt+F4").send ()	
		api.setFocusObject(bouton)
		sleep(0.1)
		bouton.doAction ()
		wx.CallLater (600,callback)
	script_fermerFenetre.__doc__ = u"Ferme la fenêre, et la fenêtre de publicité si teamviewerQS."
	script_fermerFenetre.category = _scriptCategory
	
	__gestures = {
		"kb:control+shift+i": "sayID",
		"kb:control+shift+p": "sayPasseword",
		"kb:control+shift+l": "entrerIDDistant",
		"kb:control+shift+c": "copyData",
		"kb:control+shift+k": "copyData",
		"kb:control+shift+q": "fermerFenetre",	
	}
